package com.xkrs.newpro.service.impl;

import com.xkrs.encapsulation.PromptMessageEnum;
import com.xkrs.dao.QcItemDao;
import com.xkrs.dao.QcSourceDao;
import com.xkrs.newpro.model.entity.QcItemEntity;
import com.xkrs.newpro.model.entity.QcSourceEntity;
import com.xkrs.newpro.model.qo.QcSourceQoDelete;
import com.xkrs.newpro.model.qo.QcSourceQoInsert;
import com.xkrs.newpro.service.QcSourceService;
import com.xkrs.newpro.utils.Constant;
import com.xkrs.newpro.utils.LocalDateUtils;
import com.xkrs.newpro.utils.LocalStringUtils;
import com.xkrs.util.ExcelUploadUtil;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Optional;

import static com.xkrs.encapsulation.OutputEncapsulation.outputEncapsulationObject;

@Service
public class QcSourceServiceImpl implements QcSourceService {

    private Locale locale = LocaleContextHolder.getLocale();

    @Resource
    private QcItemDao qcItemDao;

    @Resource
    private QcSourceDao qcSourceDao;

    /**
     * 添加检验数据
     */
    @Override
    public String insertQcSource(QcSourceQoInsert insertQo, MultipartFile picture) {
        String batchNo = insertQo.getBatchNo();
        String machineNo = insertQo.getMachineNo();
        String materialNo = insertQo.getMaterialNo();
        String mouldNo = insertQo.getMouldNo();
        String varietyNo = insertQo.getVarietyNo();
        String qcItemNo = insertQo.getQcItemNo();
        String qcValue = insertQo.getQcValue();
        Optional<QcItemEntity> qcItemEntityByNo = qcItemDao.findByNo(qcItemNo);
        if (qcItemEntityByNo.isEmpty()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "不存在该检验项目，请先添加检验项目！", locale);
        }
        if (Constant.QC_ITEM_TYPE_STRING.equals(qcItemEntityByNo.get().getType())) {
            QcSourceEntity entity = new QcSourceEntity();
            entity.setCreateTime(LocalDateUtils.getCurrentSecond());
            entity.setBatchNo(LocalStringUtils.formatEmptyValue(batchNo));
            entity.setMachineNo(LocalStringUtils.formatEmptyValue(machineNo));
            entity.setMaterialNo(LocalStringUtils.formatEmptyValue(materialNo));
            entity.setMouldNo(LocalStringUtils.formatEmptyValue(mouldNo));
            entity.setVarietyNo(LocalStringUtils.formatEmptyValue(varietyNo));
            entity.setQcItemNo(LocalStringUtils.formatEmptyValue(qcItemNo));
            entity.setQcValue(LocalStringUtils.formatEmptyValue(qcValue));
            qcSourceDao.save(entity);
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "添加成功！", locale);
        }
        if (Constant.QC_ITEM_TYPE_PICTURE.equals(qcItemEntityByNo.get().getType())) {
            if (picture == null) {
                return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "上传图片不能为空！", locale);
            }
            String picturePath;
            try {
                picturePath = ExcelUploadUtil.memoryFile(picture, 2);
            } catch (IOException e) {
                e.printStackTrace();
                return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "上传图片失败！", locale);
            }
            QcSourceEntity entity = new QcSourceEntity();
            entity.setCreateTime(LocalDateUtils.getCurrentSecond());
            entity.setBatchNo(LocalStringUtils.formatEmptyValue(batchNo));
            entity.setMachineNo(LocalStringUtils.formatEmptyValue(machineNo));
            entity.setMaterialNo(LocalStringUtils.formatEmptyValue(materialNo));
            entity.setMouldNo(LocalStringUtils.formatEmptyValue(mouldNo));
            entity.setVarietyNo(LocalStringUtils.formatEmptyValue(varietyNo));
            entity.setQcItemNo(LocalStringUtils.formatEmptyValue(qcItemNo));
            entity.setQcValue(LocalStringUtils.formatEmptyValue(picturePath));
            qcSourceDao.save(entity);
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "添加成功！", locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "添加失败！", locale);
    }

    /**
     * 删除检验数据
     */
    @Override
    public String deleteQcSource(QcSourceQoDelete deleteQo) {
        Integer id = deleteQo.getId();
        Optional<QcSourceEntity> entityById = qcSourceDao.findById(id);
        if (entityById.isEmpty()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "不存在该检验数据，请先添加检验数据！", locale);
        }
        qcSourceDao.deleteById(id);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "删除成功！", locale);
    }

    /**
     * 查询检验数据
     */
    @Override
    public String queryQcSource(String batchNo, String machineNo, String materialNo, String mouldNo, String varietyNo) {
        List<Map<String, Object>> resultList = qcSourceDao.queryQcSource(LocalStringUtils.formatEmptyValue(batchNo), LocalStringUtils.formatEmptyValue(machineNo), LocalStringUtils.formatEmptyValue(materialNo), LocalStringUtils.formatEmptyValue(mouldNo), LocalStringUtils.formatEmptyValue(varietyNo));
        if (resultList == null || resultList.isEmpty()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "暂时没有该检验数据的信息！", locale);
        }
        if (1 == 1) {
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS, resultList, locale);
        }




        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "查询成功！", locale);
    }
}
